pub enum TradeStatus {
Matched,
Mined,
Confirmed,
Retrying,
Failed,
}Expand description
Trade status from the CLOB API
See: https://docs.polymarket.com/#get-trades
Variants
Matched
Trade has been matched and sent to the executor service
Mined
Trade is observed to be mined into the chain, no finality threshold established
Confirmed
Trade has achieved strong probabilistic finality and was successful (terminal)
Retrying
Trade transaction has failed and is being retried/resubmitted
Failed
Trade has failed and is not being retried (terminal)
Implementations
Sourceimpl TradeStatus
impl TradeStatus
Sourcepub fn is_terminal(&self) -> bool
pub fn is_terminal(&self) -> bool
Returns true if this status is terminal (no further state changes expected)